# CHANGELOG


## v0.3.1 (2026-03-20)

### Bug Fixes

- **main**: Setapplicationname("bec")
  ([`892d915`](https://github.com/bec-project/bec_launcher/commit/892d91595228b7793b8de3d7f7b57dfb036ff855))


## v0.3.0 (2026-03-18)

### Bug Fixes

- **backend**: Default path to the bec deployments
  ([`3063b99`](https://github.com/bec-project/bec_launcher/commit/3063b99a3e2bbc58d699ebcf0bb24560d5c06c10))

### Build System

- **gui**: Added qt packages
  ([`346fd27`](https://github.com/bec-project/bec_launcher/commit/346fd2773fcdd2ec948aa77394bd0ad198e63cc3))

### Chores

- **git**: Gitignore QtDesignStudio files
  ([`e335bed`](https://github.com/bec-project/bec_launcher/commit/e335bed255158a8cf05a47955a3b3753efbc0575))

### Features

- **gui**: Qml based gui added
  ([`cd97b0c`](https://github.com/bec-project/bec_launcher/commit/cd97b0ccfb406e5c616c8671628e6d57cb0c3ac4))

- **script**: Added `launcher` script for cli
  ([`9bf8884`](https://github.com/bec-project/bec_launcher/commit/9bf888429d53b6da783e7ce8d9e919e62a026101))


## v0.2.0 (2026-01-12)

### Bug Fixes

- Correct repository reference in sync-issues-pr workflow
  ([`2f36cb8`](https://github.com/bec-project/bec_launcher/commit/2f36cb883c9ed0f83f72bea55465eccc6e3a425f))

### Features

- Add launch_deployment function for executing commands in new terminal
  ([`5d1c82d`](https://github.com/bec-project/bec_launcher/commit/5d1c82dc09be01197a7ccca5c7a80c72ab6f3437))

### Testing

- Add tests for launch_deployment function across macOS and Linux platforms
  ([`63e61fe`](https://github.com/bec-project/bec_launcher/commit/63e61fe54bd15be334bc6fc5a3b951f749b69a1e))


## v0.1.0 (2026-01-09)

### Features

- Simple launch file to demonstrate usage
  ([`4ee8761`](https://github.com/bec-project/bec_launcher/commit/4ee87619a2dad87a8cd6bd2a28bc3f8b7b05af14))

### Refactoring

- Enhance type safety by introducing DeploymentDict for deployment names
  ([`47e47da`](https://github.com/bec-project/bec_launcher/commit/47e47dac3cf3aaab5084bc4e32fbd194bf55f54d))
